require_dependency "people/application_controller"

module People
  class AccountController < ApplicationController
    before_action :set_email_hash, only: [:email_confirm, :new_password, :change_password]
    before_action :set_user, only: [:email_confirm, :new_password, :change_password]

    # GET /account/email_confirm?eh_id=:id&token=:token
    def email_confirm
      check_type(::People::EmailHash.email_confirm)
      @user.confirmed = true
      @user.save
      #Shows a page that says email confirmed
      render :email_confirm
      #Delete all of this users previous confirm emails sent
      ::People::EmailHash.delete_all({:user_id => ["user_id = ?", @user.id],
        :email_type => ["email_type = ?", ::People::EmailHash.email_confirm]})
      ::People::AccountMailer.you_confirmed_email(@user).deliver
    end

    # GET /account/forgotten_password
    #Creates the form to enter your email
    def forgotten_password
      #Shows a page that says enter email and posts to posted_email
      render :forgotten_password
    end

    # POST /account/posted_email
    def posted_email
      @user = ::People::V1::User.find_by(email: params[:email].downcase)
      if !@user.nil?
        ::People::AccountMailer.forgot_password(@user).deliver
      end
      render :posted_email_sent
    end

    # GET /account/new_password?eh_id=:id&token=:token
    #Shows the form to enter password and password_confirmation
    def new_password
      check_type(::People::EmailHash.forgotten_password)
      render :new_password
    end

    # POST /account/change_password?eh_id=:id&token=:token
    #Tries to update the user, if doesn't validate, send back to new_password
    def change_password
      check_type(::People::EmailHash.forgotten_password)
      #Shows a page that says enter new password
      #Changes the current password if it matches
      if @user.update({password: params[:password],
        password_confirmation: params[:password_confirmation]})
        @user.locked = false
        @user.attempts = 0
        @user.confirmed = true
        @user.save
        render :changed_password
        #Changing a password inadvertantly confirms your email. All other
        #Requests to change your password should be destroyed. So every
        #Email hash that belongs to a user needs to be destroyed.
        ::People::EmailHash.delete_all(:user_id => ["user_id = ?", @user.id])
        ::People::AccountMailer.password_reset(@user).deliver
      else
        render :new_password
      end
    end

    private

      def set_user
        @user = ::People::V1::User.find(@email_hash.user_id)
      end
      
      def set_email_hash
        @email_hash = ::People::EmailHash.find(params[:eh_id])
        if @email_hash.token != params[:token] || ::People::EmailHash.expired?(@email_hash)
          raise ::ActionController::RoutingError.new('Not Found')
        end
      end

      def check_type(email_type)
        if @email_hash.email_type != email_type
          raise ::ActionController::RoutingError.new('Not Found')
        end
      end
  end
end
