require 'type_cartographer'

module People
  class V1::User < ActiveRecord::Base
    self.table_name = 'people_users'
    
    before_save { self.email = email.downcase }
    before_save { self.username = username.downcase }
    before_validation :sanitize_attributes
    after_create :setup_user
  
  	has_secure_password

    has_many :tokens, :as => :imageable, :class_name => "::Arcadex::Token", dependent: :destroy
    has_many :email_hashes, :class_name => "::People::EmailHash", dependent: :destroy

    validates :username, presence: true, :uniqueness => { :case_sensitive => false }
    #validates_format_of :username, :with => /\A[A-Za-z0-9\d]+\Z/i
    validates :email, presence: true, :uniqueness => { :case_sensitive => false }
    #Might need a regex for emails, or just rather confirm them

    def sanitize_attributes
      if self.locked.nil?
        self.locked = false
      end
      if self.confirmed.nil?
        self.confirmed = false
      end
      if self.attempts.nil?
        self.attempts = 0
      end
      return true
    end

    def setup_user
    	create_token
      return true
    end

    def create_token
      self.tokens.create!
      return true
    end

    def self.over_max_attempts?(attempts)
      if attempts > 20
        return true
      else
        return false
      end
    end
  
  end
end
